# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-28 06:43
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0059_sectionattach_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserQuestionAnswerRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('answer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.SectionQuestionOption')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.SectionQuestion')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_course_user_question_answer_record',
            },
        ),
    ]
